<?php
/**
 *  Clients CPT
 */
 
if ( ! function_exists('cqpim_clients_cpt') ) {
	// Register Custom Post Type
	function cqpim_clients_cpt() {

		// Create new Client perms
 
		if(current_user_can('cqpim_create_new_client') && current_user_can('publish_cqpim_clients')) {
		 
			$client_caps = array();
		 
		} else {
		
			$client_caps = array('create_posts' => false);
			
		}	
	
	
		$labels = array(
			'name'                => __( 'Clients', 'Post Type General Name', 'cqpim' ),
			'singular_name'       => __( 'Client', 'Post Type Singular Name', 'cqpim' ),
			'menu_name'           => __( 'Clients', 'cqpim' ),
			'parent_item_colon'   => __( 'Parent Client:', 'cqpim' ),
			'all_items'           => __( 'Clients', 'cqpim' ),
			'view_item'           => __( 'View Client', 'cqpim' ),
			'add_new_item'        => __( 'Add New Client', 'cqpim' ),
			'add_new'             => __( 'New Client', 'cqpim' ),
			'edit_item'           => __( 'Edit Client', 'cqpim' ),
			'update_item'         => __( 'Update Client', 'cqpim' ),
			'search_items'        => __( 'Search Clients', 'cqpim' ),
			'not_found'           => __( 'No clients found', 'cqpim' ),
			'not_found_in_trash'  => __( 'No clients found in trash', 'cqpim' ),
		);
		$args = array(
			'label'               => __( 'client', 'cqpim' ),
			'description'         => __( 'Clients', 'cqpim' ),
			'labels'              => $labels,
			'supports'            => array( 'title' ),
			'hierarchical'        => false,
			'capabilities'        => $client_caps,
			'public'              => false,
			'show_ui'             => true,
			'show_in_nav_menus'   => false,
			'show_in_menu'		  => 'cqpim-dashboard',	
			'show_in_admin_bar'   => true,
			'menu_position'       => 5,
			'menu_icon'           => plugins_url() . "/img/contact.png",
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => true,
			'publicly_queryable'  => true,
			'capability_type'     => array('cqpim_client', 'cqpim_clients'),
			'map_meta_cap'        => true,
			'query_var'			  => true,
		);

		register_post_type( 'cqpim_client', $args );

	}
	add_action( 'init', 'cqpim_clients_cpt', 6 );
}


/**

 *	Edit 'contact' cpt columns

 */

if ( ! function_exists( 'cqpim_client_cpt_custom_columns' )){

	function cqpim_client_cpt_custom_columns( $columns ) {

		$new_columns = array(

			'title' 			=> __('Title', 'cqpim'),
			
			'company_name'      => __('Company Name', 'cqpim'),
			
			'user_account'      => __('Associated User', 'cqpim'),

			'contact_details'	=> __('Contact Details', 'cqpim')

		);
		
		unset($columns['date']);

	    return array_merge( $columns, $new_columns );

	}

	add_filter('manage_cqpim_client_posts_columns' , 'cqpim_client_cpt_custom_columns', 10, 1 );

}


/**

 *	Content for 'client' cpt columns defined above

 */



add_action( 'manage_cqpim_client_posts_custom_column', 'content_cqpim_client_cpt_columns', 10, 2 );

function content_cqpim_client_cpt_columns( $column, $post_id ) {

	global $post;

	$client_details = get_post_meta( $post_id, 'client_details', true );

	switch( $column ) {
	
		case 'company_name' :

			$company_name = isset($client_details['client_company']) ? $client_details['client_company'] : '';
			
			echo $company_name;

		break;
		
		case 'user_account' :

			$user_id = isset($client_details['user_id']) ? $client_details['user_id'] : '';
			
			$user_object = get_user_by('id', $user_id);
			
			$user_edit_link = get_edit_user_link( $user_id );
			
			echo '<strong>' . __('User ID:', 'cqpim') . ' </strong><a href="' . $user_edit_link . '">' . $user_object->ID . '</a><br />';
			
			echo '<strong>' . __('Username:', 'cqpim') . ' </strong>' . $user_object->user_email . '</strong><br />';			

		break;

		case 'contact_details' :

			$company_contact = isset($client_details['client_contact']) ? $client_details['client_contact'] : '';
			
			$company_email = isset($client_details['client_email']) ? $client_details['client_email'] : '';
			
			$company_telephone = isset($client_details['client_telephone']) ? $client_details['client_telephone'] : '';
			
			echo '<strong>' . __('Contact Name:', 'cqpim') . ' </strong>' . $company_contact . "<br />";
			
			echo '<strong>' . __('Email:', 'cqpim') . ' </strong>' . $company_email . "<br />";
			
			echo '<strong>' . __('Telephone:', 'cqpim') . ' </strong>' . $company_telephone . "<br />";

		break;

		default :

			break;

	}

} 
