<?php
/**
 *  Projects CPT
 */
 
if ( ! function_exists('cqpim_projects_cpt') ) {

	// Register Custom Post Type
	function cqpim_projects_cpt() {
	
			// Create new Client perms
 
		if(current_user_can('cqpim_create_new_project') && current_user_can('publish_cqpim_projects')) {
		 
			$project_caps = array();
		 
		} else {
		
			$project_caps = array('create_posts' => false);
			
		}	

		$labels = array(
			'name'                => __( 'Projects', 'cqpim' ),
			'singular_name'       => __( 'Project', 'cqpim' ),
			'menu_name'           => __( 'Projects', 'cqpim' ),
			'parent_item_colon'   => __( 'Parent Project:', 'cqpim' ),
			'all_items'           => __( 'Projects', 'cqpim' ),
			'view_item'           => __( 'View Project', 'cqpim' ),
			'add_new_item'        => __( 'Add New Project', 'cqpim' ),
			'add_new'             => __( 'New Project', 'cqpim' ),
			'edit_item'           => __( 'Edit Project', 'cqpim' ),
			'update_item'         => __( 'Update Project', 'cqpim' ),
			'search_items'        => __( 'Search Projects', 'cqpim' ),
			'not_found'           => __( 'No projects found', 'cqpim' ),
			'not_found_in_trash'  => __( 'No projects found in trash', 'cqpim' ),
		);
		$args = array(
			'label'               => __( 'project', 'cqpim' ),
			'description'         => __( 'Projects', 'cqpim' ),
			'labels'              => $labels,
			
			'capabilities'        => $project_caps,
			
			'map_meta_cap' => true, 
			'supports'            => array( 'title' ),
			'hierarchical'        => false,
			'public'              => false,
			'show_ui'             => true,
			'show_in_nav_menus'   => false,
			
			'show_in_menu'		  => 'cqpim-dashboard',	
			'show_in_admin_bar'   => true,
			'menu_position'       => 5,
			'menu_icon'           => plugins_url() . "/img/contact.png",
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => true,
			'publicly_queryable'  => true,
			'capability_type'     => array('cqpim_project', 'cqpim_projects'),
			'map_meta_cap'        => true,
			'query_var'			  => true,
			'rewrite'			  => array('slug' => get_option('cqpim_project_slug')),
		);

		register_post_type( 'cqpim_project', $args );

	}
	add_action( 'init', 'cqpim_projects_cpt', 9 );
}

/**

 *	Edit 'project' cpt columns

 */

if ( ! function_exists( 'cqpim_project_cpt_custom_columns' )){

	function cqpim_project_cpt_custom_columns( $columns ) {

		$new_columns = array(

			'title' 			=> __('Title', 'cqpim'),
			
			'client_details'      => __('Client Details', 'cqpim'),

			'status'	=> __('Status', 'cqpim')

		);
		
		unset($columns['date']);

	    return array_merge( $columns, $new_columns );

	}

	add_filter('manage_cqpim_project_posts_columns' , 'cqpim_project_cpt_custom_columns', 10, 1 );

}


/**

 *	Content for 'project' cpt columns defined above

 */



add_action( 'manage_cqpim_project_posts_custom_column', 'content_cqpim_project_cpt_columns', 10, 2 );

function content_cqpim_project_cpt_columns( $column, $post_id ) {

	global $post;

	$project_details = get_post_meta( $post_id, 'project_details', true );
	
	$client_id = isset($project_details['client_id']) ? $project_details['client_id'] : '';
	
	$client_contact = isset($project_details['client_contact']) ? $project_details['client_contact'] : '';
	
	$client_details = get_post_meta($client_id, 'client_details', true);
	
	$client_contacts = get_post_meta($client_id, 'client_contacts', true);
	
	if(!empty($client_contact)) {
	
		if($client_details['user_id'] == $client_contact) {
		
			$client_contact_name = isset($client_details['client_contact']) ? $client_details['client_contact'] : '';
			
			$client_company_name = isset($client_details['client_company']) ? $client_details['client_company'] : '';
			
			$client_telephone = isset($client_details['client_telephone']) ? $client_details['client_telephone'] : '';
			
			$client_email = isset($client_details['client_email']) ? $client_details['client_email'] : '';
		
		} else {
		
			$client_contact_name = isset($client_contacts[$client_contact]['name']) ? $client_contacts[$client_contact]['name'] : '';
			
			$client_company_name = isset($client_details['client_company']) ? $client_details['client_company'] : '';
			
			$client_telephone = isset($client_contacts[$client_contact]['telephone']) ? $client_contacts[$client_contact]['telephone'] : '';
			
			$client_email = isset($client_contacts[$client_contact]['email']) ? $client_contacts[$client_contact]['email'] : '';		
		
		}
	
	} else {
	
		$client_contact_name = isset($client_details['client_contact']) ? $client_details['client_contact'] : '';
		
		$client_company_name = isset($client_details['client_company']) ? $client_details['client_company'] : '';
		
		$client_telephone = isset($client_details['client_telephone']) ? $client_details['client_telephone'] : '';
		
		$client_email = isset($client_details['client_email']) ? $client_details['client_email'] : '';		
	
	}
	
	$project_sent = isset($project_details['sent']) ? $project_details['sent'] : '';
		
	$project_accepted = isset($project_details['confirmed']) ? $project_details['confirmed'] : '';
		
	$signoff = isset($project_details['signoff']) ? $project_details['signoff'] : '';
		
	$closed = isset($project_details['closed']) ? $project_details['closed'] : '';

	switch( $column ) {
	
		case 'client_details' :
		
			if($client_id) {

				echo '<strong>' . _e('Company Name:', 'cqpim') . '</strong> ' . $client_company_name . '<br />';

				echo '<strong>' . _e('Contact Name:', 'cqpim') . '</strong> ' . $client_contact_name . '<br />';
				
				echo '<strong>' . _e('Email:', 'cqpim') . '</strong> ' . $client_email . '<br />';
				
				echo '<strong>' . _e('Telephone:', 'cqpim') . '</strong> ' . $client_telephone . '<br />';
			
			} else {
			
				echo '<p>N/A</p>';
				
			}

		break;

		case 'status' :
		
		$checked = get_option('enable_project_contracts'); 
		
		if($client_id) {

			if(!$closed) {
			
				if(!$signoff) {
				
					if(!empty($checked)) {
				
						if(!$project_accepted) {
						
							if(empty($project_sent)) {
							
								echo '<div style="margin:0; text-align:left" class="unsent_quote">';
													
								_e('The contract has not yet been sent to the client.', 'cqpim');
								
								echo '</div>';
												
							}
							
							if($project_sent) {
							
								$project_sent = $project_details['sent_details'];
								
								$to = isset($project_sent['to']) ? $project_sent['to'] : '';
								
								$by = isset($project_sent['by']) ? $project_sent['by'] : '';
								
								$at = isset($project_sent['date']) ? $project_sent['date'] : '';
								
								if(is_numeric($at)) { $at = date(get_option('cqpim_date_format') . ' H:i', $at); } else { $at = $at; }
								
								echo '<div style="margin:0; text-align:left" class="sent_quote">';
								
								printf(__('This contract was sent to %1$s on %2$s by %3$s', 'cqpim'), $to, $at, $by);
								
								echo '</div>';
								
							}
						
						} else {
						
							$project_accepted = $project_details['confirmed_details'];
								
							$ip = isset($project_accepted['ip']) ? $project_accepted['ip'] : '';
								
							$by = isset($project_accepted['by']) ? $project_accepted['by'] : '';
								
							$at = isset($project_accepted['date']) ? $project_accepted['date'] : '';
							
							if(is_numeric($at)) { $at = date(get_option('cqpim_date_format') . ' H:i', $at); } else { $at = $at; }

							echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
							
							printf(__('The contract was accepted by %1$s on %2$s from IP Address %3$s', 'cqpim'), $by, $at, $ip);
							
							echo '</div>';
					
						}	
					
					} else {
					
						echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
						
						_e('Project in Progress', 'cqpim');
						
						echo '</div>';					
					
					}
				
				} else {
				
					$project_signedoff = $project_details['signoff_details'];
						
					$by = isset($project_signedoff['by']) ? $project_signedoff['by'] : '';
						
					$at = isset($project_signedoff['at']) ? $project_signedoff['at'] : '';	
					
					if(is_numeric($at)) { $at = date(get_option('cqpim_date_format') . ' H:i', $at); } else { $at = $at; }
					
					echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
					
					printf(__('This project was signed off by %1$s on %2$s', 'cqpim'), $by, $at);
					
					echo '</div>';
				}
			
			} else {
			
				$project_closed = $project_details['closed_details'];
						
				$by = isset($project_closed['by']) ? $project_closed['by'] : '';
						
				$at = isset($project_closed['at']) ? $project_closed['at'] : '';

				if(is_numeric($at)) { $at = date(get_option('cqpim_date_format') . ' H:i', $at); } else { $at = $start_date; }				

				echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
					
				printf(__('This project was closed by %1$s on %2$s', 'cqpim'),$by, $at);
					
				echo '</div>';			
			
			}
			
		} else {
		
			if(!$closed) {
		
				echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
				
				_e('This is not a client project, no contract needs to be signed.', 'cqpim');
				
				'</div>';

			} else {
			
				$project_closed = $project_details['closed_details'];
						
				$by = isset($project_closed['by']) ? $project_closed['by'] : '';
						
				$at = isset($project_closed['at']) ? $project_closed['at'] : '';
				
				if(is_numeric($at)) { $at = date(get_option('cqpim_date_format') . ' H:i', $at); } else { $at = $start_date; }

				echo '<div style="margin:0; text-align:left" class="confirmed_quote">';
					
				printf(__('This project was closed by %1$s on %2$s', 'cqpim'), $by, $at);
					
				echo '</div>';		

			}		
		
		}

		break;

		default :

			break;

	}

} 
